@@ -22,10 +22,10 @@
 #include <string.h>
 #include <syslog.h>
 
-#include <loc/libloc.h>
-#include <loc/database.h>
-#include <loc/network.h>
-#include <loc/writer.h>
+#include <libloc/libloc.h>
+#include <libloc/database.h>
+#include <libloc/network.h>
+#include <libloc/writer.h>
 
 int main(int argc, char** argv) {
 	int err;
